==> oddmuse-1.612.tar.gz: oddmuse-1.612/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

CGI Internal error: %s

Invalid action parameter %s

Invalid URL.

Page name is missing

Page name is too long: %s

Invalid Page %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Page name may not contain space characters: %s

Preview:

Preview only, not yet saved

Please go on to %s.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Could not open old %s log file

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

List only major changes

Include minor changes

%s days

List later changes

Filters

Title:

Title and Body:

Username:

Host:

Language:

Go!

(minor)

rollback

new

from %s

This page is too big to send over RSS.

History of %s

Compare

Revision %s

by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Last edited

Edited

by %s

(diff)

Edit revision %s of this page

Edit this page

e

This page is read-only

View other revisions

View current revision

View all changes

Homepage URL:

s

Save

Preview

Search:

f

Replace:

Validate HTML

Validate CSS

Difference (from revision %1 to %2)

revision %s

current revision

Difference (from prior %s revision)

major

minor

No diff available.

The two revisions are the same.

Old revision:

Changed:

Removed:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Comments on this page

Editing not allowed for %s.

SampleUndefinedPage

%s cannot be defined.

Sample_Undefined_Page

[[%s]] cannot be defined.

Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see hidden pages.

Only Admins are allowed to see hidden pages.

image: %s

Index

Languages:

Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

  Please allow time for the webmaster to approve your request.

  An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

<p>Logout of %s?</p>

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s

The username "%s" does not exist.

Reset Password for %s

<p>Reset Password?</p>

Change Password for %s

<p>Change Password?</p>

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Rebuild index for searching

Rebuilding Index

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Tag

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Upload of %s file

Blog

Matching pages:

New

Edit %s.

END_OF_TRANSLATION

==> oddmuse-1.684.tar.gz: oddmuse-1.684/new-utf8.pl <==
# UTF-8 encoded FIXME translation file for use with Oddmuse
#
# Copyright (c) 2004  FIXME
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: new-utf8.pl,v 1.9 2006/05/10 22:52:16 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s

Invalid UserName %s: not saved.

UserName must be 50 characters or less: not saved

This page contains an uploaded file:

Recursive include of %s!

XML::RSS is not available on this system.

diff

history

%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

CGI Internal error: %s

Invalid action parameter %s

Invalid URL.

Page name is missing

Page name is too long: %s

Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Preview:

Preview only, not yet saved

Please go on to %s.

Could not open %s log file

Error was

Note: This error is normal if no changes have been made.

Could not open old %s log file

No updates since %s

Updates since %s

Updates in the last %s days

Updates in the last %s day

for %s only

List latest change per page only

List all changes

List only major changes

Include minor changes

%s days

List later changes

Filters

Title:

Title and Body:

Username:

Host:

Language:

Go!

(minor)

rollback

new

from %s

This page is too big to send over RSS.

History of %s

Compare

Revision %s

by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages

Wiki Version

Unlock Wiki

Password

Run maintenance

Unlock site

Lock site

Install CSS

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]

redirected from %s

Click to search for references to this page

Cookie: 

Warning

Database is stored in temporary directory %s

%s seconds

The same page on other sites:

EditNearLinks

Last edited

Edited

by %s

(diff)

Edit revision %s of this page

Edit this page

e

This page is read-only

View other revisions

View current revision

View all changes

Homepage URL:

s

Save

p

Preview

Search:

f

Replace:

Validate HTML

Validate CSS

Difference (from revision %1 to %2)

revision %s

current revision

Difference (from prior %s revision)

major

minor

No diff available.

The two revisions are the same.

Old revision:

Changed:

Removed:

Added:

to

Revision %s not available

showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Edit Denied

Editing not allowed: user, ip, or network is blocked.

Contact the wiki administrator for more information.

The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.

Only administrators can upload files.

Editing revision %s of

Editing %s

Editing old revision %s.

Saving this page will replace the latest revision with this text.

Summary:

This change is a minor edit.

Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.

You are currently an editor on this site.

You are a normal user on this site.

Your password does not match any of the  administrator or editor passwords.

Password:

This site does not use admin or editor passwords.

This operation is restricted to site editors only...

This operation is restricted to administrators only...

Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

Filter:

%s pages found.

Replaced: %s

Search for: %s

View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Comments on this page

Editing not allowed for %s.

SampleUndefinedPage

%s cannot be defined.

Sample_Undefined_Page

[[%s]] cannot be defined.

Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Copy one of the following stylesheets to %s:

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Cannot rename %1 to %2

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Learn more...

Cannot highlight the language %s.

Recent Visitors

some action

was here

and read

Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment

ordinary changes

Footnotes:

Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:

Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.

The password must be at least %s characters.

That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.

Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 

None

Type

Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

You did not answer correctly.

All Referrers

Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)

Slideshow:%s

Static Copy

Back to %s

Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Upload of %s file

Blog

Matching pages:

New

Edit %s.

END_OF_TRANSLATION
